coefficient_headmap: Scalp distribution of the scores on each of the pERPs

Description Usage Arguments Value

View source: R/coefficient_headmap.R

Description

This function will create a heatmap of scalp distribution of the scores on each of the pERPs.

Usage

1
coefficient_headmap(task, scores)

Arguments

task

The string for one of the tasks used to estimate the pERPs.

scores

A dataframe of scores calculated for the task. In the case of multiple tasks to be compared, use a named list of dataframes where the names are the tasks.

Value

A ggplot of with the headmaps of the scores averaged within the task for each pERP


emjcampos/pERPred documentation built on June 23, 2021, 6:18 p.m.