modeler: Modeler

Description Usage Arguments Value

View source: R/modeler.R

Description

This function will regress the individual record on the estimated pERPs, we will need to demean the record before regression.

Usage

1
modeler(df, pERPs)

Arguments

df

A dataframe containing a single record from the observed data.

pERPs

The estimated pERPs from the pERP-RED algorithm.

Value

The linear model from regressing the observed record on the estimated pERPs.


emjcampos/pERPred documentation built on June 23, 2021, 6:18 p.m.