pERP_scorer: pERP_scorer

Description Usage Arguments Value

View source: R/modeler.R

Description

This function calculates all of the individual score values.

Usage

1
pERP_scorer(df, pERPs)

Arguments

df

A dataframe containing all of the observed ERP records.

pERPs

The estimated pERPs from the pERP-RED algorithm.

Value

The dataframe containing each individual score for each of the records.


emjcampos/pERPred documentation built on June 23, 2021, 6:18 p.m.