pERPred: Principle ERP Reduction

Description Usage Arguments Value

View source: R/pERPred.R

Description

This function will contain the estimation algorithm of the principle ERPs (pERPs).

Usage

1
2
3
4
5
6
pERPred(
  df,
  num_pERPs = 20,
  percent_variation_electrode = 80,
  percent_variation_subject = 80
)

Arguments

df

The dataframe with a column for Task, Subject, and Time. The remaining columns are the Electrodes.

num_pERPs

The number of pERPs to estimate.

percent_variation_electrode

The percent variation to use in the electrode PCA step.

percent_variation_subject

The percent variation to use in the subject PCA step.

Value

pERPs The prinicple ERPs (pERPs) are the bases functions estimated by the pERP-RED algorithm.


emjcampos/pERPred documentation built on June 23, 2021, 6:18 p.m.