shiny_pERPs: Shiny App pERP Explorer

Description Usage Arguments Value

View source: R/shiny_pERPs.R

Description

In our paper, we often referenced a Shiny app in order to explore all of the results from the pERP-space analysis. Now you can, too! This function will take all of your data and results and launch a shiny application on your machine.

Usage

1
shiny_pERPs(data, groups, pERPs, scores)

Arguments

data

A dataframe containing all of the ERP data used to calculate the pERPs. One column for Task, Subject, and Time, and the rest are electrodes with the ERP data in the rows.

groups

A dataframe containing Subject, which should have the same form as the Subject column in the data, and Group, a group membership indicator.

pERPs

A dataframe containing the pERPs. This is the resulting dataframe from running 'pERPred'.

scores

A dataframe containing each of the individual scores from regressing the observed data on the pERPs. This is the resulting dataframe from running 'pERP_scorer'.

Value

shiny application


emjcampos/pERPred documentation built on June 23, 2021, 6:18 p.m.