sum_of_squares_calc: sum_of_squares_calc

Description Usage Arguments Value

View source: R/R2_test.R

Description

This function will regress one record from the observed data on the estimated pERPs at a time and calculate the variance of the residuals and the variance of the observed signal to be used in the global R2 calculation.

Usage

1

Arguments

df

The observed data, typically the test set.

pERPs

The estimated pERPs from the pERP-RED algorithm.

Value

a dataframe containing the number of pERPs and the associated R2_test value


emjcampos/pERPred documentation built on June 23, 2021, 6:18 p.m.