Description Usage Arguments Value
View source: R/coefficient_headmap.R
This function will create a heatmap of scalp distribution of the scores on each of the pERPs.
1 | coefficient_headmap(task, scores)
|
task |
The string for one of the tasks used to estimate the pERPs. |
scores |
A dataframe of scores calculated for the task. In the case of multiple tasks to be compared, use a named list of dataframes where the names are the tasks. |
A ggplot of with the headmaps of the scores averaged within the task for each pERP
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.