Description Usage Arguments Value
This function will regress the individual record on the estimated pERPs, we will need to demean the record before regression.
1 |
df |
A dataframe containing a single record from the observed data. |
pERPs |
The estimated pERPs from the pERP-RED algorithm. |
The linear model from regressing the observed record on the estimated pERPs.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.