Description Usage Arguments Value
This function calculates all of the individual score values.
1 | pERP_scorer(df, pERPs)
|
df |
A dataframe containing all of the observed ERP records. |
pERPs |
The estimated pERPs from the pERP-RED algorithm. |
The dataframe containing each individual score for each of the records.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.