Description Usage Arguments Value
This function will contain the estimation algorithm of the principle ERPs (pERPs).
1 2 3 4 5 6 |
df |
The dataframe with a column for Task, Subject, and Time. The remaining columns are the Electrodes. |
num_pERPs |
The number of pERPs to estimate. |
percent_variation_electrode |
The percent variation to use in the electrode PCA step. |
percent_variation_subject |
The percent variation to use in the subject PCA step. |
pERPs The prinicple ERPs (pERPs) are the bases functions estimated by the pERP-RED algorithm.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.