Description Usage Arguments Value
In our paper, we often referenced a Shiny app in order to explore all of the results from the pERP-space analysis. Now you can, too! This function will take all of your data and results and launch a shiny application on your machine.
1 | shiny_pERPs(data, groups, pERPs, scores)
|
data |
A dataframe containing all of the ERP data used to calculate the pERPs. One column for Task, Subject, and Time, and the rest are electrodes with the ERP data in the rows. |
groups |
A dataframe containing Subject, which should have the same form as the Subject column in the data, and Group, a group membership indicator. |
pERPs |
A dataframe containing the pERPs. This is the resulting dataframe from running 'pERPred'. |
scores |
A dataframe containing each of the individual scores from regressing the observed data on the pERPs. This is the resulting dataframe from running 'pERP_scorer'. |
shiny application
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.