Description Usage Arguments Value
This function will regress one record from the observed data on the estimated pERPs at a time and calculate the variance of the residuals and the variance of the observed signal to be used in the global R2 calculation.
1 | sum_of_squares_calc(df, pERPs)
|
df |
The observed data, typically the test set. |
pERPs |
The estimated pERPs from the pERP-RED algorithm. |
a dataframe containing the number of pERPs and the associated R2_test value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.